function [f1,f2]=fbpdp(zs,p,ts)
% fbpdp		- Shows behavior of functions in dew,bubble point calculations
% function [f1,f2]=fbpdp(zs,p,ts)
% Argument List:
% Argument    Gives
%    zs      Liquid or vapor mol fractions.
%    p       pressure in kPa
%    ts      vector of temperatures in Tdeg.
% Two functions used to solve for the bubble and dew points 
%    of a mixture with composition zs.
% Vectors of fk(t) are returned where:
%    f1 is 1-sum(zs*kval(t,p))
%    f2 is 1-sum(zs/kval(t,p))
% Example: start301   to specify the compounds
%          ts=350:2:420;
%          zs=[.4 .4 .2];
%          [f1,f2]=fbpdp(zs,101,ts);
n=length(ts);
f1=[]; f2=[];
for k=1:n
   ks=kval(ts(k),p);
   f1=[f1 1-sum(zs.*ks)];
   f2=[f2 1-sum(zs./ks)];
end
